==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridcompute/kotlin/inputs/GetPrivateLinkScopePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcompute.kotlin.inputs

import com.pulumi.azurenative.hybridcompute.inputs.GetPrivateLinkScopePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property scopeName The name of the Azure Arc PrivateLinkScope resource.
 */
public data class GetPrivateLinkScopePlainArgs(
    public val resourceGroupName: String,
    public val scopeName: String,
) : ConvertibleToJava<com.pulumi.azurenative.hybridcompute.inputs.GetPrivateLinkScopePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridcompute.inputs.GetPrivateLinkScopePlainArgs =
        com.pulumi.azurenative.hybridcompute.inputs.GetPrivateLinkScopePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .scopeName(scopeName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPrivateLinkScopePlainArgs].
 */
@PulumiTagMarker
public class GetPrivateLinkScopePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var scopeName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("lhtcjkelaavytdsv")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Azure Arc PrivateLinkScope resource.
     */
    @JvmName("deumqexkdrqswslw")
    public suspend fun scopeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.scopeName = mapped
    }

    internal fun build(): GetPrivateLinkScopePlainArgs = GetPrivateLinkScopePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        scopeName = scopeName ?: throw PulumiNullFieldException("scopeName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridcompute/kotlin/inputs/GetPrivateLinkScopePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcompute.kotlin.inputs

import com.pulumi.azurenative.hybridcompute.inputs.GetPrivateLinkScopePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property scopeName The name of the Azure Arc PrivateLinkScope resource.
 */
public data class GetPrivateLinkScopePlainArgs(
    public val resourceGroupName: String,
    public val scopeName: String,
) : ConvertibleToJava<com.pulumi.azurenative.hybridcompute.inputs.GetPrivateLinkScopePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridcompute.inputs.GetPrivateLinkScopePlainArgs =
        com.pulumi.azurenative.hybridcompute.inputs.GetPrivateLinkScopePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .scopeName(scopeName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPrivateLinkScopePlainArgs].
 */
@PulumiTagMarker
public class GetPrivateLinkScopePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var scopeName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("hpcypcrwpwgrfakq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Azure Arc PrivateLinkScope resource.
     */
    @JvmName("xihdrfnrglqjgahh")
    public suspend fun scopeName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.scopeName = mapped
    }

    internal fun build(): GetPrivateLinkScopePlainArgs = GetPrivateLinkScopePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        scopeName = scopeName ?: throw PulumiNullFieldException("scopeName"),
    )
}
